@@ -58,23 +58,23 @@
 #' @return A list containing:
 #' \item{beta}{The fitted values from the regression. Taken to be the more stable fit between \code{x} and \code{z}, which is usually the former. A filter is applied to remove very small values, where ATOS has not been able to shrink exactly to zero. Check this against \code{x} and \code{z}.}
 #' \item{group_effects}{The group values from the regression. Taken by applying the \eqn{\ell_2} norm within each group on \code{beta}.}
-#' \item{selected_var}{A list containing the indicies of the active/selected variables for each \code{"lambda"} value.}
-#' \item{selected_grp}{A list containing the indicies of the active/selected groups for each \code{"lambda"} value.}
-#' \item{pen_gslope}{Vector of the group penalty sequence.}
-#' \item{lambda}{Value(s) of \eqn{\lambda} used to fit the model.}
-#' \item{type}{Indicates which type of regression was performed.}
-#' \item{standardise}{Type of standardisation used.} 
-#' \item{intercept}{Logical flag indicating whether an intercept was fit.}
+#' \item{selected_var}{A list containing the indicies of the active/selected variables for each \code{"lambda"} value. Index 1 corresponds to the first column in X.}
+#' \item{selected_grp}{A list containing the indicies of the active/selected groups for each \code{"lambda"} value. Index 1 corresponds to the first group in the \code{groups} vector.}
 #' \item{num_it}{Number of iterations performed. If convergence is not reached, this will be \code{max_iter}.}
 #' \item{success}{Logical flag indicating whether ATOS converged, according to \code{tol}.}
-#' \item{certificate}{Final value of convergence criteria.} 
+#' \item{certificate}{Final value of convergence criteria.}
 #' \item{x}{The solution to the original problem (see Pedregosa and Gidel (2018)).}
 #' \item{u}{The solution to the dual problem (see Pedregosa and Gidel (2018)).}
 #' \item{z}{The updated values from applying the first proximal operator (see Pedregosa and Gidel (2018)).}
 #' \item{screen_set}{List of groups that were kept after screening step for each \code{"lambda"} value. (corresponds to \eqn{\mathcal{S}} in Feser and Evangelou (2024)).}
 #' \item{epsilon_set}{List of groups that were used for fitting after screening for each \code{"lambda"} value. (corresponds to \eqn{\mathcal{E}} in Feser and Evangelou (2024)).}
-#' \item{kkt_violations}{List of groups that violated the KKT conditions each \code{"lambda"} value. (corresponds to \eqn{\mathcal{K}} in Feser and Evangelou (2024)).}  
+#' \item{kkt_violations}{List of groups that violated the KKT conditions each \code{"lambda"} value. (corresponds to \eqn{\mathcal{K}} in Feser and Evangelou (2024)).}
+#' \item{pen_gslope}{Vector of the group penalty sequence.}
 #' \item{screen}{Logical flag indicating whether screening was applied.}
+#' \item{type}{Indicates which type of regression was performed.}
+#' \item{intercept}{Logical flag indicating whether an intercept was fit.}
+#' \item{standardise}{Type of standardisation used.}
+#' \item{lambda}{Value(s) of \eqn{\lambda} used to fit the model.}
 #' 
 #' @family gSLOPE-methods
 #' 
@@ -101,5 +101,9 @@ fit_goscar <- function(X, y, groups, type="linear", lambda="path", path_length=2
   }
   out = general_fit(X, y, groups, "gslope", gen_path_gslope, NULL, gslope_grp_screen, gslope_kkt_check, type, lambda, path_length, 0, 0.1, 0.1, 3, 
                       backtracking, max_iter, max_iter_backtracking, tol, min_frac, standardise, intercept, NULL, w_weights, screen, verbose, FALSE, FALSE)
+  
+  out$beta = 
+  out$group_effects = 
+
   return(out)
 }
\ No newline at end of file
