@@ -693,3 +693,11 @@ estimateNoise <- function(X, y, intercept = TRUE) {
   fit <- stats::lm.fit(X, y)
   sqrt(sum(fit$residuals^2) / (n - p + intercept))
 }
+
+check_group_vector <- function(vec) {
+  # Check if the vector is sorted and has no gaps
+  is_sorted <- all(diff(vec) >= 0)
+  has_no_gaps <- all(diff(unique(vec)) == 1)
+  
+  return(is_sorted && has_no_gaps)
+}
\ No newline at end of file
